# tree level analyses for Revision for Ecology, Berthelot et al.: "Exotic tree species have consistently lower herbivore load in a cross-Atlantic tree biodiversity experiment"
# Jochen Fründ and Sylvie Berthelot (2021-Dec-20 to 2023-Apr-05)

# new approach (as requested for Revision 1 in Ecology): 
# model a) for objective 1:
  # (resp ~ site*genus*native_status + (1|site.plot)) # using all data (not just monocultures)
  # in addition, (resp ~ phylodist*native_status + (1|site.plot)) as alternative model (for checking the influence of phylodist); or a better meta-analysis (of estimates from summaries?); include an overall significant intercept (when appicable)
  # figure should be per genus, showing site-dependent native/exotic effect (difference instead of the two means?) ("pattern flipped"?)
# model b) for objective 2:
  # (resp ~ log(SR)*native_status + (1|site/site.plot) + (log(SR)*native_status|TreeSpecies)  # better testing of "overall effect", but may not converge so random effects might have to be simplified

#----
# This is the version for upload to Dryad, so some internal comments / notes have been cleaned up, and data cleaning has been moved out of this script (data cleaning code available upon request, e.g. internal version as of 2023-01-31)

# load data --------------
# arthropod abundance data
datapertree <- read.csv(file="datapertree.csv")
# create factors
datapertree$genus_tree <- factor(datapertree$genus_tree, levels=c("Acer", "Betula", "Quercus", "Larix", "Picea", "Pinus"))
datapertree$native_status <- factor(datapertree$native_status, levels=c("native", "exotic"))
datapertree$TreeSpecies <- factor(datapertree$TreeSpecies, levels=c("ACPL", "ACSA", "BEPA", "BEPE", "LADE", "LALA", "PIAB", "PIGL", "PIST", "PISY", "QURO", "QURU"))

# leaf damage data 
leafd.pertree <- read.csv(file="leafd.pertree.csv")
# create factors
leafd.pertree$genus_tree <- factor(leafd.pertree$genus_tree, levels=c("Acer", "Betula", "Quercus", "Larix", "Picea", "Pinus"))
leafd.pertree$native_status <- factor(leafd.pertree$native_status, levels=c("native", "exotic"))
leafd.pertree$TreeSpecies <- factor(leafd.pertree$TreeSpecies, levels=c("ACPL", "ACSA", "BEPA", "BEPE", "LADE", "LALA", "PIAB", "PIGL", "PIST", "PISY", "QURO", "QURU"))

#-------------------------------------------------------------------------------
# Analyses (tree-level mixed models) -------------------------------------------
#-------------------------------------------------------------------------------

# Various preparations -----
summary(as.data.frame(lapply(datapertree, factor)))
hist(datapertree$Freq_Herbivores)
hist(log(datapertree$Freq_Herbivores+1))
table(datapertree$site, datapertree$Freq_Herbivores, useNA="ifany")
#--> now previous issues fixed: treeIDs really unique, zeros included for both sites

# packages for models:
library(glmmTMB)  # for fitting the models
library(lmerTest) # for fitting damage models
library(car) # for Anova; maybe not needed in the end, or for interactions
library(DHARMa) # diagnostics

# packages for figures:
library(ggplot2) # effect plots / ggplot style plotting
library(ggeffects) # for marginal effects (averaging over other predictors)
library(egg) # for multi-plots
# library(grid) # for multi-plots
# library(gridExtra) # for multi-plots

# structure of model setup now (see more in above notes, combine notes there):
# H1 (model m1...), without SR in the model, emphasis on per genus (& site) differences / congruence
  # should it include 3way interaction (or consider it, choosing by AIC)?
  # do subset tests per genus? / in plot?
  # include phylo in here or in meta-analysis?
  # mono subsets as check?
# H2 (model m2...), with species as random effect, testing overall effects with only the core fixed effects model
  # for interpretation it is important if native_status effect is still significant for SR=6


# figure settings ----
# define size parameters
tt = 16
al = 16 # axis label # 10
at = 16 # axis title # 10
lw = 2 # line width

theme_1 = theme_bw() + theme(strip.background = element_rect(colour="white", fill="white"), 
                             plot.title = element_text(size = tt),
                             legend.text = element_text(size = al),
                             axis.text = element_text(size = al, colour = "black"), axis.title = element_text(size = at, colour = "black"), 
                             panel.grid=element_blank(), panel.background = element_blank(), 
                             panel.border = element_rect(colour = "black", fill = NULL),
                             legend.title = element_text(size = at), legend.key.size = unit(1,"line"),
                             axis.line = element_line(color = 'black'), strip.text = element_text(size = at)) +
  theme(aspect.ratio = 1) 
# aspect ratio: forces the output of square plots : , aspect.ratio = 1; this is added to the plots with continous predictors
theme_2 <- theme_1 + theme(aspect.ratio = 0.7)

# The palette with grey:
cbp1 <- c("#FFDB6D", "#C4961A", "#D16103", "#52854C", "#4E84C4", "#293352")



#** H1: Herbivores  --------------------
# first do nb1 vs nb2 selection
m1.herb.nb1 <- glmmTMB(Freq_Herbivores ~ (site + genus_tree + native_status)^3 + (1|site.plot), data = datapertree, family=nbinom1)
m1.herb.nb2 <- glmmTMB(Freq_Herbivores ~ (site + genus_tree + native_status)^3 + (1|site.plot), data = datapertree, family=nbinom2)
AIC(m1.herb.nb1, m1.herb.nb2) #--> nb2 much better
m1.herb <- m1.herb.nb2  # choosing the better model

# DHARMa model checks
sim_m1.herb <- simulateResiduals(m1.herb)
plot(sim_m1.herb)  # KS-test n.s.; accepting the model despite a bit remaining overdispersion and very slight curve in residual vs predicted

# testing significance of interactions incl genus
Anova(m1.herb, type=3)
summary(m1.herb)

#--- check: using abundance extrapolated to whole tree
m1.HerbTotal <- lmer(log(Total_Herbivores + 1) ~ (site + genus_tree + native_status)^3 + (1|site.plot), data=datapertree)

# DHARMa model checks
sim_m1.HerbTotal <- simulateResiduals(m1.HerbTotal)
plot(sim_m1.HerbTotal)  # not nice: KS test highly significant, strong curve in qqplot

opar <- par(no.readonly = TRUE)
par(mar=c(8,4,1,1))
boxplot(log(Total_Herbivores+1) ~ (native_status + site + genus_tree)^3, data=datapertree, las=2, xlab="")
par(opar)
anova(m1.HerbTotal)
#--> the combined evidence of boxplot and anova show that patterns are qualitatively similar, but not seriously testable for these extrapolated values due to their untenable distributions


#** H1: Suckers  --------------------
# first do nb1 vs nb2 selection
m1.suck.nb1 <- glmmTMB(Freq_Suckers ~ (site + genus_tree + native_status)^3 + (1|site.plot), data = datapertree, family=nbinom1)
m1.suck.nb2 <- glmmTMB(Freq_Suckers ~ (site + genus_tree + native_status)^3 + (1|site.plot), data = datapertree, family=nbinom2)
AIC(m1.suck.nb1, m1.suck.nb2) #--> nb2 much better
m1.suck <- m1.suck.nb2  # choosing the better model

# DHARMa model checks
sim_m1.suck <- simulateResiduals(m1.suck)
plot(sim_m1.suck)  # KS-test n.s.; accepting the model despite a bit remaining overdispersion and very slight curve in residual vs predicted

# testing significance of interactions incl genus
Anova(m1.suck, type=3)


#** H1: Chewers.adult  --------------------
# first do nb1 vs nb2 selection
m1.achew.nb1 <- glmmTMB(Freq_Chewers.adult ~ (site + genus_tree + native_status)^3 + (1|site.plot), data = datapertree, family=nbinom1)
m1.achew.nb2 <- glmmTMB(Freq_Chewers.adult ~ (site + genus_tree + native_status)^3 + (1|site.plot), data = datapertree, family=nbinom2)
AIC(m1.achew.nb1, m1.achew.nb2) #--> nb2 clearly better
m1.achew <- m1.achew.nb2  # choosing the better model

# DHARMa model checks
sim_m1.achew <- simulateResiduals(m1.achew)
plot(sim_m1.achew)  # KS-test n.s.; accepting the model, looks good (I would say)

# testing significance of interactions incl genus
Anova(m1.achew, type = 3)

#** H1: Chewers.larva  --------------------
# first do nb1 vs nb2 selection (HERE going to Poisson instead)
m1.lchew.nb1 <- glmmTMB(Freq_Chewers.larva ~ (site + genus_tree + native_status)^3 + (1|site.plot), data = datapertree, family=nbinom1)
m1.lchew.nb2 <- glmmTMB(Freq_Chewers.larva ~ (site + genus_tree + native_status)^3 + (1|site.plot), data = datapertree, family=nbinom2)
# --> convergence issues for both binomial models. Trying poisson (as for nb2 the dispersion param was estimated at e12)
m1.lchew <- glmmTMB(Freq_Chewers.larva ~ (site + genus_tree + native_status)^3 + (1|site.plot), data = datapertree, family=poisson) # Trying poisson instead of nbinom; no overdispersion detected in next step!

# DHARMa model checks
sim_m1.lchew <- simulateResiduals(m1.lchew)
plot(sim_m1.lchew)  # KS-test n.s.; accepting the model, looks good (I would say)

# testing significance of interactions incl genus
Anova(m1.lchew, type=3)


#** H1: Leaf damage  --------------------

# nlme alternative: but not supported by DHARMa
  # library(nlme)  # should I use lmer instead?
  # m1.damage <- lme(log(totalDamage + 1) ~ (site + genus_tree + native_status)^3, random=~1|site.plot, data=leafd.pertree)

library(lmerTest)
m1.damage <- lmer(log(totalDamage + 1) ~ (site + genus_tree + native_status)^3 + (1|site.plot), data=leafd.pertree)

summary(m1.damage)  
anova(m1.damage)  
# plot(m1.damage)

# DHARMa model checks: only works for the lmer version
sim_m1.damage <- simulateResiduals(m1.damage)
plot(sim_m1.damage)  # terrible!

#--> especially the DHARMa plot for the lmer model shows that the model is inacceptable!!
#--> leaving out conifers once again
  # (or use zero inflation?? or use damage incidence?? or use beta regression???)

# only broadleafs
m1.damage <- lmer(log(totalDamage + 1) ~ (site + genus_tree + native_status)^3 + (1|site.plot), data=leafd.pertree, subset=genus_tree %in% c("Acer", "Betula", "Quercus"))

# DHARMa model checks: 
sim_m1.damage <- simulateResiduals(m1.damage)
plot(sim_m1.damage)  # looks fine (after changing the transformation to log(y+1), which is more appropriate for % values

# testing significance of interactions incl genus
anova(m1.damage, type=3)
# testing main effect (possible for lmer)
anova(m1.damage, type=1)

summary(m1.damage)


#-- all Figures for H1: Figure 1 --------
# the CI are +-1.96*SE (https://strengejacke.github.io/ggeffects/articles/ggeffects.html)
# backtransformation had to be done manually for leaf damage

# plot for herb: ggeffects without ggplot (native plot function of ggeffect)
effects.herb <- ggeffect(m1.herb, terms = c("site","native_status","genus_tree")) 
p1.effects.herb <- plot(effects.herb)
p1.effects.herb <- p1.effects.herb + labs(tag="(a)", title=NULL) + theme(legend.position = "none") + ylab("Herbivore abundance per tree") + scale_colour_manual(values=c("cornflowerblue", "red"))
# p1.effects.herb

# plot for suck: ggeffects without ggplot (native plot function of ggeffect)
effects.suck <- ggeffect(m1.suck, terms = c("site","native_status","genus_tree"))
p1.effects.suck <- plot(effects.suck)
p1.effects.suck <- p1.effects.suck + labs(tag="(b)", title=NULL) + theme(legend.position = "none") + ylab("Sucker abundance per tree") + scale_colour_manual(values=c("cornflowerblue", "red"))
# p1.effects.suck

# plot for achew: ggeffects without ggplot (native plot function of ggeffect)
effects.achew <- ggeffect(m1.achew, terms = c("site","native_status","genus_tree")) 
p1.effects.achew <- plot(effects.achew)
p1.effects.achew <- p1.effects.achew + labs(tag="(c)", title=NULL) + theme(legend.position = "none") + ylab("Adult chewer abundance per tree") + scale_colour_manual(values=c("cornflowerblue", "red"))
# p1.effects.achew

# plot for damage: ggeffects without ggplot (native plot function of ggeffect)
# ("log(total damage +1) per tree")
effects.damage <- ggeffect(m1.damage, terms = c("site","native_status","genus_tree"), back.transform=T) 
effects.damage[, c(2,4,5)]  <- exp(effects.damage[,c(2,4,5)])-1  # manual backtransformation
p1.effects.damage <- plot(effects.damage)
p1.effects.damage <- p1.effects.damage + labs(tag="(d)", title=NULL) + theme(legend.position = "bottom", legend.direction="vertical") + ylab("Leaf damage per tree") + scale_colour_manual("Native status", values=c("cornflowerblue", "red"))
# p1.effects.damage

# figure compilation
# beware that this is egg::ggarrange, not to be confused with functions with same name from other packages; https://cran.r-project.org/web/packages/egg/vignettes/Overview.html
# ggarrange(p1.effects.herb, p1.effects.suck, p1.effects.achew, p1.effects.damage, nrow = 2, labels=c("(a)","(b)","(c)","(d)"))
Figure1 <- grid.arrange(p1.effects.herb, p1.effects.suck, p1.effects.achew, p1.effects.damage, nrow = 2)
# ggsave("Figure1.pdf",Figure1, width=9, height=8, unit="in")


# figure for larval chewers: Supplement
# Figure (version 1): ggeffects without ggplot (native plot function of ggeffect)
effects.lchew <- ggeffect(m1.lchew, terms = c("site","native_status","genus_tree"))
p1.effects.lchew <- plot(effects.lchew)
p1.effects.lchew <- p1.effects.lchew + labs(tag="(a)", title=NULL) + ylab("Larval chewer abundance per tree") + scale_colour_manual("native status", values=c("cornflowerblue", "red"))
# p1.effects.lchew


#** extra1: phylogenetic distance predicts Enemy release? --------------------
# using it instead of genus in model m1.herb (just there, cause too little power for other variables)
m1extra.herb.nb2 <- glmmTMB(Freq_Herbivores ~ site*native_status + sqrt(phylodist)*native_status +  (1|site.plot), data = datapertree, family=nbinom2)
summary(m1extra.herb.nb2)

# there were more ideas, but this is the one most consistent with overall modeling strategy
# I would say it is quite clear that phylogeny is insignificant. Could also add the values to Figure (H1 Herbivores)

# for a more condensed plot, could show the difference between log(native) and log(exotic) as enemy release effect
phylodist <- c(Acer=18, Betula=35, Quercus=31, Larix=35, Picea=113, Pinus=72) # data taken from Tab S2 from first submission Ecology, Picea in Freiburg is actually 88 
metadf <- data.frame(genus_tree=character(0), site=character(0), Estimate=numeric(0), StdError=numeric(0))
for (mygen in levels(datapertree$genus_tree)){
  for (mysite in c("AU", "FR")){
    mymod <- glmmTMB(Freq_Herbivores ~ native_status + (1|site.plot), data = subset(datapertree, genus_tree==mygen & site==mysite), family=nbinom2)
    myrow <- nrow(metadf)+1
    metadf[myrow,1:2] <- c(mygen, mysite)
    metadf[myrow,3:4] <- summary(mymod)$coefficients$cond[2,1:2]
  }
}
metadf$ER_effect <- metadf$Estimate # inverse Estimate to be a "reduction"
metadf$phylodist <- phylodist[metadf$genus_tree]
metadf[metadf$site=="FR"& metadf$genus_tree=="Picea", "phylodist"] <- 88

# pdf(file="Figure2_phyloEffect.pdf", width=5,height=5) # with CI = 1.96*SE
# par(mar=c(5,5,1,1))
# plot(ER_effect ~ phylodist, data=metadf, pch=ifelse(metadf$site=="AU",21,24), bg=rep(c("green2", "darkgreen"), each=6), col=rep(c("green", "darkgreen"), each=6), las=1, ylim=c(-2.4,0.7), xlab="Phylogenetic distance within genus", ylab="Effect  of exotic status on herbivore abundance", bty="l", cex=1.3)
# arrows(metadf$phylodist, y0=metadf$ER_effect-metadf$StdError*1.96, y1=metadf$ER_effect+metadf$StdError*1.96, angle=90, code=3, length=0.05,  col=rep(c("green2", "darkgreen"), each=6), lwd=1.3)
# legend("topright", pch=c(21,24), legend=c("AU","FR"), title="Site", pt.bg="grey", col="grey")
# dev.off()

# version with tiny x-shifts ("real jitter") to improve readibility;
pdf(file="Figure2_phyloEffect.pdf", width=5,height=5) # with CI = 1.96*SE
par(mar=c(5,5,1,1))
set.seed(5)
metadf$phylo.jit <- jitter(metadf$phylodist, factor=1.8)
plot(ER_effect ~ phylo.jit, data=metadf, pch=ifelse(metadf$site=="AU",21,24), bg=rep(c("green2", "darkgreen"), each=6), col=rep(c("green", "darkgreen"), each=6), las=1, ylim=c(-2.4,0.7), xlab="Phylogenetic distance within genus", ylab="Effect  of exotic status on herbivore abundance", bty="l", cex=1.3) # with "jitter" shift
abline(h=0,col="grey")
arrows(metadf$phylo.jit, y0=metadf$ER_effect-metadf$StdError*1.96, y1=metadf$ER_effect+metadf$StdError*1.96, angle=90, code=3, length=0.05,  col=rep(c("green2", "darkgreen"), each=6), lwd=1.3)
legend("topright", pch=c(21,24), legend=c("AU","FR"), title="Site", pt.bg="grey", col="grey")
dev.off()

#** extra2: Chewers vs Damage -------
leafd.pertree$TreeUID[!(leafd.pertree$TreeUID %in% datapertree$TreeIDunique)]  # 12 trees in AU have damage data but no arthropod data. Correct? Expected?
# adding the chewer columns to leafd.pertree
leafd.pertree <- merge(leafd.pertree, datapertree[, c("TreeIDunique", "Freq_Chewers.adult", "Freq_Chewers.larva")], by.x="TreeUID", by.y="TreeIDunique", all.x = TRUE)  #! corrected for Revision! here, all.x was missing, which caused the 12 trees (6 broadleaved) to be dropped also from further analyses (also main H2 damage results!)

plot(log(ChewerDamage + SkeletoniserDamage + 1) ~ jitter(I(Freq_Chewers.adult + Freq_Chewers.larva)), data=subset(leafd.pertree, genus_tree %in% c("Acer", "Betula", "Quercus")), col=as.numeric(as.factor(subset(leafd.pertree, genus_tree %in% c("Acer", "Betula", "Quercus"))$site)), pch=as.numeric(as.factor(subset(leafd.pertree, genus_tree %in% c("Acer", "Betula", "Quercus"))$native_status)))

# only site and number of chewers as predictors in mixed model
m3.chewvsdamage <- lmer(log(ChewerDamage + SkeletoniserDamage + 1) ~ I(Freq_Chewers.adult + Freq_Chewers.larva)*site + (1|site.plot), data = subset(leafd.pertree, genus_tree %in% c("Acer", "Betula", "Quercus")))
plot(m3.chewvsdamage)
summary(m3.chewvsdamage)

# Chewers equivalent to total?
with(leafd.pertree, sum(ChewerDamage) / sum(totalDamage)) # 97.51 %
with(subset(leafd.pertree, genus_tree %in% c("Acer", "Betula", "Quercus")), sum(ChewerDamage) / sum(totalDamage)) # 97.46 %
with(leafd.pertree, cor(ChewerDamage, totalDamage)) # 99.6 %
with(subset(leafd.pertree, genus_tree %in% c("Acer", "Betula", "Quercus")), cor(ChewerDamage, totalDamage)) # 99.5 %


#** extra3: explicit guild comparison (status by guild interaction) ----
dpertreenew <- datapertree[,-which(names(datapertree)=="Freq")]
datapertree.guildstack <- reshape(dpertreenew, varying = names(dpertreenew)[grep("Freq_", names(dpertreenew))], direction="long", sep="_", timevar="Guild")
data_combi <- subset(datapertree.guildstack, Guild %in% c("Suckers", "Chewers.adult"))
# a model with both main guilds and their interaction!
m1.2guilds <- glmmTMB(Freq ~ (site + genus_tree + native_status)^3 + Guild*native_status + (1|site.plot/TreeIDunique), data = data_combi, family=nbinom2)
sim_m1.2guilds <- simulateResiduals(m1.2guilds)
plot(sim_m1.2guilds)  # KS-test n.s.; accepting the model despite a bit remaining overdispersion and very slight curve in residual vs predicted
Anova(m1.2guilds, type=3)
summary(m1.2guilds)


#++ H2: Herbivores -----------
# Notes:
  # I moved site from random to fixed (only 2 levels, and much better in DHARMa);
  # I also tried dispersion~site, but it didn't change anything so went back to before
  # I am sticking to nbinom2 here (as it was clearly better for H1 models)
  # ziformula = ~ 1 did not change anything either
m2.herb <- glmmTMB(Freq_Herbivores ~ site + native_status*log(SR) + (1|site.plot) + (native_status*log(SR)|TreeSpecies), data = datapertree, family=nbinom2)
# if convergence issues (overparametrized random effects), reducing the random slope per species stepwise
#--> removing log(SR) from random slope
m2.herb <- glmmTMB(Freq_Herbivores ~ site + native_status*log(SR) + (1|site.plot) + (native_status|TreeSpecies), data = datapertree, family=nbinom2)
# modification incl. site interactions (as needed for LeafDamage)
# m2.herb <- glmmTMB(Freq_Herbivores ~ (site + native_status+log(SR))^2 + (1|site.plot) + (native_status|TreeSpecies), data = datapertree, family=nbinom2)

# DHARMa model checks
sim_m2.herb <- simulateResiduals(m2.herb)
plot(sim_m2.herb)  # KS-test n.s.; accepting the model despite a bit remaining over(?)dispersion and slight curve in residual vs predicted
# against predictors: not sure where this gets me...
  plotResiduals(sim_m2.herb, form=datapertree$site)
  plotResiduals(sim_m2.herb, form=datapertree$TreeSpecies) # PISY deviates positively, ACPL and QURU negatively

# testing significance of parameters of interest (can use summary here)  
summary(m2.herb)
# all parameters are interpretable here: site effect, Enemy release for monocultures, diversity effect for natives, and interaction ER*SR


#--- check: using abundance extrapolated to whole tree
library(lmerTest)
m2.HerbTotal <- lmer(log(Total_Herbivores + 1) ~ site + native_status*log(SR) + (1|site.plot) + (native_status|TreeSpecies), data=datapertree)

# DHARMa model checks
sim_m2.HerbTotal <- simulateResiduals(m2.HerbTotal)
plot(sim_m2.HerbTotal)  # not nice: KS test highly significant, strong curve in qqplot

summary(m2.HerbTotal)
anova(m2.HerbTotal,type=1)
#--> as in model m1: model with "whole tree abundance" is not acceptable, but shows same results as the model used


#++ H2: Suckers -----------
m2.suck <- glmmTMB(Freq_Suckers ~ site + native_status*log(SR) + (1|site.plot) + (native_status*log(SR)|TreeSpecies), data = datapertree, family=nbinom2)
# if convergence issues (overparametrized random effects), reducing the random slope per species stepwise
#--> removing log(SR) from random slope
m2.suck <- glmmTMB(Freq_Suckers ~ site + native_status*log(SR) + (1|site.plot) + (native_status|TreeSpecies), data = datapertree, family=nbinom2)

# DHARMa model checks
sim_m2.suck <- simulateResiduals(m2.suck)
plot(sim_m2.suck)  # KS-test n.s.; accepting the model despite slight curve in residual vs predicted

# testing significance of parameters of interest (can use summary here)  
summary(m2.suck)
# all parameters are interpretable here: site effect, Enemy release for monocultures,  diversity effect for natives, and interaction ER*SR


#++ H2: Chewers.adult -----------
m2.achew <- glmmTMB(Freq_Chewers.adult ~ site + native_status*log(SR) + (1|site.plot) + (native_status*log(SR)|TreeSpecies), data = datapertree, family=nbinom2)
# if convergence issues (overparametrized random effects), reducing the random slope per species stepwise
#--> removing all of random slope
m2.achew <- glmmTMB(Freq_Chewers.adult ~ site + native_status*log(SR) + (1|site.plot) + (1|TreeSpecies), data = datapertree, family=nbinom2)

# DHARMa model checks
sim_m2.achew <- simulateResiduals(m2.achew)
plot(sim_m2.achew)  # KS-test n.s.; accepting the model despite very slight curve in residual vs predicted

# testing significance of parameters of interest (can use summary here)  
summary(m2.achew)
# all parameters are interpretable here: site effect, Enemy release for monocultures,  diversity effect for natives, and interaction ER*SR


#++ H2: Chewers.larva -----------
m2.lchew <- glmmTMB(Freq_Chewers.larva ~ site + native_status*log(SR) + (1|site.plot) + (native_status*log(SR)|TreeSpecies), data = datapertree, family=nbinom2)
# if convergence issues (overparametrized random effects), reducing the random slope per species stepwise
#--> removing log(SR) from random slope
m2.lchew <- glmmTMB(Freq_Chewers.larva ~ site + native_status*log(SR) + (1|site.plot) + (native_status|TreeSpecies), data = datapertree, family=nbinom2)
# trying poisson (dispersion fitted in nbinom was e+06)
# m2.lchew <- glmmTMB(Freq_Chewers.larva ~ site + native_status*log(SR) + (1|site.plot) + (native_status|TreeSpecies), data = datapertree, family=poisson) #--> no, outlier test significant

# DHARMa model checks
sim_m2.lchew <- simulateResiduals(m2.lchew)
plot(sim_m2.lchew)  # KS-test n.s.; accepting the model despite significant dispersion test

# testing significance of parameters of interest (can use summary here)  
summary(m2.lchew)
# all parameters are interpretable here: site effect, Enemy release for monocultures,  diversity effect for natives, and interaction ER*SR


#++ H2: Leaf Damage -------------
library(lmerTest)
m2.damage <- lmer(log(totalDamage + 1) ~ site + native_status*log(SR) + (1|site.plot) + (native_status*log(SR)|TreeSpecies), data = leafd.pertree)
# if convergence issues (overparametrized random effects), reducing the random slope per species stepwise
#--> removing log(SR) from random slope
m2.damage <- lmer(log(totalDamage + 1) ~ site + native_status*log(SR) + (1|site.plot) + (native_status|TreeSpecies), data = leafd.pertree)

# DHARMa model checks
sim_m2.damage <- simulateResiduals(m2.damage)
plot(sim_m2.damage)  # ugly!! heteroscedasticity and more

# only broadleafs
leafd.pertree.broadleaf <- subset(leafd.pertree, genus_tree %in% c("Acer", "Betula", "Quercus"))
m2.damage <- lmer(log(totalDamage + 1) ~ site + native_status*log(SR) + (1|site.plot) + (native_status|TreeSpecies), data = leafd.pertree.broadleaf)

# following code: DHARMa revealed problems, which I found to be missing interactions with site! 
  # some attempts to improve model (which had issues in DHARMa)
m2.damage <- lmer(log(totalDamage+1) ~ (site+native_status+log(SR))^2 + (1|site.plot) + (native_status|TreeSpecies), data = leafd.pertree.broadleaf)
  plot(m2.damage)
  plot(residuals(m2.damage) ~ leafd.pertree.broadleaf$SR)
  lines(c(1,2,6),tapply(residuals(m2.damage),leafd.pertree.broadleaf$SR, mean))
  plot(residuals(m2.damage) ~ leafd.pertree.broadleaf$native_status)
  
  # DHARMa model checks
  sim_m2.damage <- simulateResiduals(m2.damage)
  plot(sim_m2.damage)  # dispersion is better, but strong nonlinearity (without the interactions with site)
  # trying to understand it better
  plotResiduals(sim_m2.damage, form=leafd.pertree.broadleaf$SR)
  plotResiduals(sim_m2.damage, form=log(leafd.pertree.broadleaf$SR))
  plotResiduals(sim_m2.damage, form=leafd.pertree.broadleaf$native_status)
  plotResiduals(sim_m2.damage, form=leafd.pertree.broadleaf$site)
  plotResiduals(sim_m2.damage, form=leafd.pertree.broadleaf$TreeSpecies)
  plotResiduals(sim_m2.damage, form=leafd.pertree.broadleaf$native_status )
  # strange errors when trying conditional simulations (object 'SR' not found)
  
  # testing predictors
  summary(m2.damage)

# checking zero-inflation
  m2plus.damage <- glmmTMB(log(totalDamage + 1) ~ site + native_status*log(SR) + (1|site.plot) + (native_status|TreeSpecies), data = leafd.pertree)
  m2pluszi.damage <- glmmTMB(log(totalDamage + 1) ~ site + native_status*log(SR) + (1|site.plot) + (native_status|TreeSpecies), ziformula = ~1, data = leafd.pertree)
  m2pluszi2.damage <- glmmTMB(log(totalDamage + 1) ~ site + native_status*log(SR) + (1|site.plot) + (native_status|TreeSpecies), ziformula = ~genus_tree, data = leafd.pertree)
  AIC(m2plus.damage, m2pluszi.damage, m2pluszi2.damage)
  
  # DHARMa model checks
  sim_m2pluszi.damage <- simulateResiduals(m2pluszi2.damage)
  plot(sim_m2pluszi.damage)  # better than it was, but still ugly!
  
  summary(m2pluszi.damage)

  
#-- all Figures for H2: Figure 3 --------

# figure Herbivores
effects2.herb <- ggeffect(m2.herb, terms = ~log(SR)*native_status)
p2.effects.herb <- plot(effects2.herb)
p2.effects.herb <- p2.effects.herb  + xlab("Tree species richness") + ylab("Herbivore abundance per tree") + scale_x_continuous(breaks=c(1,2,6), trans="log") + scale_fill_manual(values = c("cornflowerblue","red")) + scale_color_manual(values=c("cornflowerblue","red")) + theme(legend.position = "none") + labs(tag="(d)", title=NULL)
# p2.effects.herb

# figure Suckers
effects2.suck <- ggeffect(m2.suck, terms = ~log(SR)*native_status)
p2.effects.suck <- plot(effects2.suck)
p2.effects.suck <- p2.effects.suck + xlab("Tree species richness") + ylab("Sucker abundance per tree") + scale_x_continuous(breaks=c(1,2,6), trans="log") + scale_fill_manual(values = c("cornflowerblue","red")) + scale_color_manual("Native status",values=c("cornflowerblue","red")) + labs(tag="(d)", title=NULL)
#p2.effects.suck

# figure Ad Chewers
effects2.achew <- ggeffect(m2.achew, terms = ~log(SR)*native_status)
p2.effects.achew <- plot(effects2.achew)
p2.effects.achew <- p2.effects.achew + xlab("Tree species richness") + ylab("Adult chewer abundance per tree")  + scale_x_continuous(breaks=c(1,2,6), trans="log") + scale_fill_manual(values = c("cornflowerblue","red")) + scale_color_manual(values=c("cornflowerblue","red")) + theme(legend.position = "none") + labs(tag="(d)", title=NULL)
# p2.effects.achew

# figure Damage
effects2.damage <- ggeffect(m2.damage, terms = ~log(SR)*native_status)
effects2.damage[, c(2,4,5)]  <- exp(effects2.damage[,c(2,4,5)])-1  # manual backtransformation
p2.effects.damage <- plot(effects2.damage)
p2.effects.damage <- p2.effects.damage + xlab("Tree species richness") + ylab("Leaf damage per tree") + scale_x_continuous(breaks=c(1,2,6), trans="log")+ scale_fill_manual(values = c("cornflowerblue","red")) + scale_color_manual("native status", values=c("cornflowerblue","red")) + theme(legend.position = "none") + labs(tag="(d)", title=NULL)
# p2.effects.damage

# Figures combined
Figure3 <- ggarrange(p2.effects.herb, p2.effects.suck, p2.effects.achew, p2.effects.damage, nrow = 2, labels=c("(a)","(b)","(c)","(d)"), label.args = list(gp = grid::gpar(font = 1, cex =  1)))
ggsave("Figure3.pdf", Figure3, width=9, height=7, unit="in")

# Supplement: figure larv chewers
effects2.lchew <- ggeffect(m2.lchew, terms = ~log(SR)*native_status)
p2.effects.lchew <- plot(effects2.lchew)
p2.effects.lchew <- p2.effects.lchew + labs(tag="(b)", title=NULL) + ylab("Larval chewer abundance per tree") + scale_x_continuous(breaks=c(1,2,6)) + xlab("Tree species richness") + scale_fill_manual(values = c("cornflowerblue","red")) + scale_color_manual("native status", values=c("cornflowerblue","red"))
# p2.effects.lchew
# VERY LOW numbers... one caterpillar on every 20th tree

# Figure S1a,b (larval chewers, BOTH hypotheses!)
FigureS1 <- grid.arrange(p1.effects.lchew, p2.effects.lchew, nrow=1)
ggsave("FigureS1.pdf", FigureS1, width=10, height=4, unit="in")


#-- Supplement: other arthropod groups  --------------------
# summary: also for these, native > exotic significant; a trend towards less difference with high SR, but not significant

# Predators ------------
m1.pred <- glmmTMB(Freq_Predators ~ (site + genus_tree + native_status)^3 + (1|site.plot), data = datapertree, family=nbinom2)
Anova(m1.pred, type=3)

m2.pred <- glmmTMB(Freq_Predators ~ site + native_status*log(SR) + (1|site.plot) + (native_status|TreeSpecies), data = datapertree, family=nbinom2)
summary(m2.pred)

# "Other" Guild -------------
m1.other <- glmmTMB(Freq_Others ~ (site + genus_tree + native_status)^3 + (1|site.plot), data = datapertree, family=nbinom2)
Anova(m1.other, type=3)

m2.other <- glmmTMB(Freq_Others ~ site + native_status*log(SR) + (1|site.plot) + (native_status|TreeSpecies), data = datapertree, family=nbinom2)
summary(m2.other)

